<?php

namespace Andy\DuplicateAccountCheck\XF\Cron;

class DuplicateAccountCheck
{
	public static function runDuplicateAccountCheck()
	{	
		// get options
		$options = \XF::options();
		
		// get options from Admin CP -> Options -> Duplicate account check -> Email to username
		$emailToUsername = $options->duplicateAccountCheckEmailToUsername;
        
        //########################################
        // check emailToUsername is valid
        
        // get result
        $finder = \XF::finder('XF:User');
        $result = $finder
            ->where('username', $emailToUsername)
            ->fetchOne();
        
        // get emailToUserId
        $emailToUserId = $result['user_id'];

		// check condition
		if (empty($emailToUserId))
		{
			\XF::app()->error()->logError("Duplicate account check. Email to username in options not set.");
			return;
		}
        
        //########################################
        // delete old rows

		// get timestamp
		$timestamp = time() - (3600 * 24);

        // get results
        $finder = \XF::finder('Andy\DuplicateAccountCheck:DuplicateAccountCheck');
        $results = $finder
            ->where('view_date', '<', $timestamp)
            ->fetch();
        
        // foreach condition
        foreach ($results AS $result)
        {
            $result->delete();
        }
        
        //########################################
        // check for duplicate accounts
        
		// get timeNow
		$timeNow = time();  

		// get floor   
		$floor = floor($timeNow/600)*600;

		// get datelineStart
		$datelineStart = $floor - (600);									

		// get datelineEnd
		$datelineEnd = $floor;

        // get results
        $finder = \XF::finder('Andy\DuplicateAccountCheck:DuplicateAccountCheck');
        $results = $finder
            ->where('User.register_date', '>=', $datelineStart)
            ->where('User.register_date', '<=', $datelineEnd)
            ->fetch();

        // foreach condition
        foreach ($results AS $k => $v)
        {
            // get result
            $finder = \XF::finder('XF:User');
            $result = $finder
                ->where('user_id', $v['user_id'])
                ->fetchOne();
            
            // check condition
            if (!empty($result))
            {
                 // get results2
                $finder = \XF::finder('Andy\DuplicateAccountCheck:DuplicateAccountCheck');
                $results2 = $finder
                    ->where('user_id', '<>', $v->user_id)
                    ->where('ip', $v['ip'])
                    ->where('user_agent', $v['user_agent'])
                    ->fetch();

                // get results2Count
                $results2Count = count($results2);

                // check condition
                if ($results2Count > 0)
                {
                    // foreach condition
                    foreach ($results2 AS $k2 => $v2)
                    {
                        $conditionsOr[] = ['user_id', '=', $v2->user_id];
                    }

                    // get conditionsOr
                    $conditionsOr[] = ['user_id', '=', $v->user_id];

                    // get user
                    $finder = \XF::finder('Andy\DuplicateAccountCheck:DuplicateAccountCheck');
                    $users = $finder
                        ->whereOr($conditionsOr)
                        ->fetch();

                    //########################################
                    // send email

                    $mail = \XF::app()->mailer()->newMail();

                    $user = \XF::app()->find('XF:User', $emailToUserId);
                    $mail->setToUser($user);

                    $mail->setTemplate('andy_duplicateaccountcheck', [
                        'users' => $users
                    ]);

                    $mail->queue();
                }
            }
        }
    }
}